#!/usr/bin/env python

import sys, os, commands

try:
    wiki_dir, archive_dir = sys.argv[1:3]
except ValueError:
    print "For archiving, please specify the Wiki directory and a target archive directory."
    print "For restoring, please specify the archive directory and a target Wiki directory."
    sys.exit(1)

dry_run = ("-n" in sys.argv)

pages = os.path.join(wiki_dir, "wiki", "data", "pages")
users = os.path.join(wiki_dir, "wiki", "data", "user")

# Make the archive's page directory.

archive_pages = os.path.join(archive_dir, "wiki", "data", "pages")
if not dry_run and not os.path.exists(archive_pages):
    os.makedirs(archive_pages)

archive_users = os.path.join(archive_dir, "wiki", "data", "user")
if not dry_run and not os.path.exists(archive_users):
    os.makedirs(archive_users)

# Copy user details.

print "Copying users..."
if not dry_run:
    cmd = "cp %s %s" % (os.path.join(users, "*"), archive_users)
    print cmd
    os.system(cmd)

# Find active Wiki pages.

for page in os.listdir(pages):
    page_dir = os.path.join(pages, page)

    if os.path.isdir(page_dir) and "current" in os.listdir(page_dir):

        f = open(os.path.join(page_dir, "current"))
        try:
            current = f.read().strip()
        finally:
            f.close()

        archive_page_dir = os.path.join(archive_pages, page)
        archive_page_revisions = os.path.join(archive_page_dir, "revisions")
        page_revisions = os.path.join(page_dir, "revisions")

        if current not in os.listdir(page_revisions):
            continue

        print "Archiving", page
        print "Revision", current

        if not dry_run:
            if not os.path.exists(archive_page_revisions):
                os.makedirs(archive_page_revisions)

            f = open(os.path.join(archive_page_dir, "current"), "w")
            try:
                f.write("00000001")
            finally:
                f.close()

        cmd = "cp %s %s" % tuple(
            map(commands.mkarg, (os.path.join(page_revisions, current), os.path.join(archive_page_revisions, "00000001")))
            )
        print cmd
        if not dry_run:
            os.system(cmd)

        attachments_dir = os.path.join(page_dir, "attachments")
        if os.path.exists(attachments_dir):
            print "Archiving attachments..."

            archive_attachments_dir = os.path.join(archive_page_dir, "attachments")
            if not dry_run and not os.path.exists(archive_attachments_dir):
                os.mkdir(archive_attachments_dir)

            cmd = "cp %s %s" % (
                os.path.join(commands.mkarg(attachments_dir), "*"), commands.mkarg(archive_attachments_dir)
                )
            print cmd
            if not dry_run:
                os.system(cmd)

        print

print "Now run the following, if adding to a live Wiki:"
print "chown -R www-data: %s" % os.path.join(archive_dir, "wiki")

# vim: tabstop=4 expandtab shiftwidth=4
